uabCTRAFrameGroup = uabFrameGroup:NewModule("CTRA")

uabCTRAFrameGroup.controls = {}
uabCTRAFrameGroup.defaultDB = {
    framegroups = {
        ["Main Tank"] = {
            expression = "^CT_RAMTGroupUnitButton%d$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Main Tank Target"] = {
            expression = "^CT_RAMTTGroupUnitButton%d$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Player Target"] = {
            expression = "^CT_RAPTGroupUnitButton%d$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Player Target Target"] = {
            expression = "^CT_RAPTTGroupUnitButton%d$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Raid Frames"] = {
            expression = "^CT_RAGroup%dUnitButton%d$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
    },
}

function uabCTRAFrameGroup:OnInitialize()
    self.super.OnInitialize(self)
end

function uabCTRAFrameGroup:OnEnable()
end

function uabCTRAFrameGroup:OnDisable()
end

function uabCTRAFrameGroup:NewActivator(activator)
    --[[
    We create 6 controls for the partyraid unit group, since
    the CTRA frames will go into that group, and there are 6
    possible frames to be allocated for each unit (each person
    could be a player target and a MT.
    --]]
	self.controls[activator] = {}
    self.controls[activator].partyraid = {}
	for idx = 1, uab.constants.groupInfo.partyraid.unitcount do
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
        table.insert(self.controls[activator].partyraid, activator:NewUnitGroupControl("partyraid"))
    end
end

function uabCTRAFrameGroup:HaveFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)
	
	if not options then return end

	if self.controls[activator] and self.controls[activator][options.unitgroup] then
		return # self.controls[activator][options.unitgroup] > 0
	end
end

function uabCTRAFrameGroup:NextFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)

	if not options then return end
	
    if self.controls[activator] and self.controls[activator][options.unitgroup]
        and # self.controls[activator][options.unitgroup] > 0 then
		control = table.remove(self.controls[activator][options.unitgroup])
	end

	return control
end

function uabCTRAFrameGroup:OptionsForFrame(frame)
    for name, defn in pairs(self.db.profile.framegroups) do
        if self:MatchFrame(frame, defn) then
            return name, defn
        end
    end
end

function uabCTRAFrameGroup:CreateFrameGroupOptions()
    local args = {}

    args = {
        type = 'group',
        name = "CTRA",
        desc = "Use, anchor, scale, and match expression for the CTRA frames",
        args = {
            enabled = {
                type = 'toggle',
                name = "Enabled",
                desc = "When checked, enable the use of UAB action sets for CTRA frames",
                order = 1,
                get = function()
                    return not self.db.profile.disabled
                end,
                set = function(v)
                    self.db.profile.disabled = not v
                    self.core.core.main:FrameGroupsChanged()
                end,
            },
            
            spacing3 = {
                name = " ",
                type = 'header',
                order = 5,
            },
        
        },
    }
    
    args.args["Main Tank"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Main Tank"], "Main Tank", "CTRA Main Tank")
    args.args["Main Tank"].disabled = function() return self.db.profile.disabled end
    args.args["Main Tank"].order = 10
    
    args.args["Main Tank Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Main Tank Target"], "Main Tank Target", "CTRA Main Tank Target")
    args.args["Main Tank Target"].disabled = function() return self.db.profile.disabled end
    args.args["Main Tank Target"].order = 20
    
    args.args["Player Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Target"], "Player Target", "CTRA Player Target")
    args.args["Player Target"].disabled = function() return self.db.profile.disabled end
    args.args["Player Target"].order = 40
    
    args.args["Player Target Target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Target Target"], "Player Target Target", "CTRA Player Target Target")
    args.args["Player Target Target"].disabled = function() return self.db.profile.disabled end
    args.args["Player Target Target"].order = 50
    
    args.args["Raid Frames"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Raid Frames"], "Raid Frames", "CTRA Raid Frames")
    args.args["Raid Frames"].disabled = function() return self.db.profile.disabled end
    args.args["Raid Frames"].order = 60
    
    return args
end

function uabCTRAFrameGroup:SetupLayouts()
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Main Tank"].layout, self, "Main Tank")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Main Tank Target"].layout, self, "Main Tank Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Player Target"].layout, self, "Player Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Player Target Target"].layout, self, "Player Target Target")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["Raid Frames"].layout, self, "Raid Frames")
end

function uabCTRAFrameGroup:SetLayoutConfigureOptions(name, args)
    self.core.core.options.args.lookandfeel.args.framegroups.args[self.name].args[name].args.layout.args.configure.args = args
end

